#[non_exhaustive]pub enum GlBackendError {
NoFont,
MixedGlyphSizes,
FontChainTooLarge,
ZeroScale,
ZeroGrid,
SurfaceTooLarge,
Tileset(TilesetError),
}Expand description
Errors from configuring the GL backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoFont
No font was provided and the default-font feature is not enabled.
MixedGlyphSizes
The fonts in the configured FontChain disagree on their glyph size.
FontChainTooLarge
The configured FontChain has more glyphs in total than the atlas can address.
ZeroScale
scale was set to 0, which would produce a zero-size surface.
ZeroGrid
The grid was configured with a zero column or row count.
SurfaceTooLarge
cols, rows, and scale combine to a surface wider or taller than u32::MAX physical
pixels.
Tileset(TilesetError)
A registered tileset failed to decode (issue #366).